==> haskell-hjsmin-0.2.0.4-106-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hjsmin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hjsmin
version:              0.2.0.4
visibility:           public
id:                   hjsmin-0.2.0.4-5PFZgPlQB2YAy9kbaNy7YQ
key:                  hjsmin-0.2.0.4-5PFZgPlQB2YAy9kbaNy7YQ
license:              BSD-3-Clause
maintainer:           Erik de Castro Lopo <erikd@mega-nerd.com>
author:               Alan Zimmerman <alan.zimm@gmail.com>
stability:            unstable
homepage:             http://github.com/erikd/hjsmin
synopsis:             Haskell implementation of a javascript minifier
description:
    Reduces size of javascript files by stripping out extraneous whitespace and
    other syntactic elements, without changing the semantics.

category:             Web
abi:                  1d3a2fb53e89f6095ccc005b02e3f80d
exposed:              True
exposed-modules:      Text.Jasmine
import-dirs:          /usr/lib/ghc-8.10.4/site-local/hjsmin-0.2.0.4
library-dirs:         /usr/lib/ghc-8.10.4/site-local/hjsmin-0.2.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/hjsmin-0.2.0.4
hs-libraries:         HShjsmin-0.2.0.4-5PFZgPlQB2YAy9kbaNy7YQ
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    language-javascript-0.7.1.0-LiqNykVTx9L29eYdjJi3a0 text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-hjsmin/html/hjsmin.haddock
haddock-html:         /usr/share/doc/haskell-hjsmin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hjsmin-0.2.0.4-108-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hjsmin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hjsmin
version:              0.2.0.4
visibility:           public
id:                   hjsmin-0.2.0.4-LNzWKU1HgBwJ5c07WWcC5D
key:                  hjsmin-0.2.0.4-LNzWKU1HgBwJ5c07WWcC5D
license:              BSD-3-Clause
maintainer:           Erik de Castro Lopo <erikd@mega-nerd.com>
author:               Alan Zimmerman <alan.zimm@gmail.com>
stability:            unstable
homepage:             http://github.com/erikd/hjsmin
synopsis:             Haskell implementation of a javascript minifier
description:
    Reduces size of javascript files by stripping out extraneous whitespace and
    other syntactic elements, without changing the semantics.

category:             Web
abi:                  6a06009110cbd23c88edace6be73a232
exposed:              True
exposed-modules:      Text.Jasmine
import-dirs:          /usr/lib/ghc-8.10.4/site-local/hjsmin-0.2.0.4
library-dirs:         /usr/lib/ghc-8.10.4/site-local/hjsmin-0.2.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/hjsmin-0.2.0.4
hs-libraries:         HShjsmin-0.2.0.4-LNzWKU1HgBwJ5c07WWcC5D
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    language-javascript-0.7.1.0-LiqNykVTx9L29eYdjJi3a0 text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-hjsmin/html/hjsmin.haddock
haddock-html:         /usr/share/doc/haskell-hjsmin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
